Feature gate registry for the TOML test runner.
Tests declare requires = ["feature1", "feature2"]. If any required
feature is not in the implemented set, the test is skipped.
Functions
- implemented_
features - Returns the set of features currently implemented in wasmsh.
- missing_
features - Check which required features are missing.