Module oracle

Module oracle 

Oracle comparison: run shell scripts against local reference shells.

Enabled via WASMSH_ORACLE=1 environment variable. Requires bash or busybox ash to be installed on the host.

Structs

OracleResult
Result from an oracle shell execution.

Functions

compare_oracle
Compare wasmsh output against oracle output.
run_oracle
Run a script against a reference shell. Returns None if the shell is not available or oracle mode is disabled.