Oracle comparison: run shell scripts against local reference shells.
Enabled via WASMSH_ORACLE=1 environment variable. Requires bash
or busybox ash to be installed on the host.
Structs
- Oracle
Result - Result from an oracle shell execution.
Functions
- compare_
oracle - Compare wasmsh output against oracle output.
- run_
oracle - Run a script against a reference shell. Returns
Noneif the shell is not available or oracle mode is disabled.